#
# spec file for package aelfred
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aelfred
Version:        7.0
Release:        10.3
Summary:        Java-based XML parser
License:        BSD-3-Clause
Group:          Development/Libraries/Java
URL:            https://saxon.sourceforge.net/aelfred.html
Source0:        http://downloads.sourceforge.net/project/saxon/aelfred/7.0/aelfred7_0.zip
Patch0:         aelfred-icedtea-build.patch
Patch1:         aelfred-javadoc.patch
BuildRequires:  ant
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-tools
BuildRequires:  unzip
BuildArch:      noarch

%description
AElfred is a Java-based XML parser from Microstar Software Ltd. AElfred
is distributed for free (with full source) for both commercial and
non-commercial use.

%package javadoc
Summary:        Java-based XML parser (documentation)
Group:          Development/Libraries/Java

%description javadoc
Javadoc for aelfred.

%package demo
Summary:        Java-based XML parser (demo and samples)
Group:          Development/Libraries/Java
Requires:       %{name} = %{version}-%{release}

%description demo
Demonstrations and samples for aelfred.

%prep
%setup -q -c
rm *.jar
unzip %{name}-source.zip
%patch -P 0
%patch -P 1 -p1

%build
mkdir -p classes
javac -source 8 -target 8 -d classes `find net -name \*.java`
javadoc -notimestamp -source 8 -d HTML `find net -name \*.java`
jar \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 17}%{!?pkg_vcmp:0}
    --date="$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ)" \
%endif
    --create --file=%{name}.jar -C classes .

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}
install -pm 0644 %{name}.jar %{buildroot}%{_javadir}/%{name}.jar

# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -a HTML/* %{buildroot}%{_javadocdir}/%{name}
%fdupes -s %{buildroot}%{_javadocdir}/%{name}

%files
%{_javadir}/%{name}.jar

%files javadoc
%{_javadocdir}/%{name}

%changelog
* Sun Sep 29 2024 Fridrich Strba <fstrba@suse.com>
- Fix build after removal of the default %%%%{java_home} define
- Refactor the spec file to actually build the jar and not just
  to distribute the prebuilt one
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Sat Mar 19 2022 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * aelfred-javadoc.patch
    + fix build with javadoc 17
* Tue May 15 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
* Wed Jan 10 2018 bwiedemann@suse.com
- Generate javadoc without timestamp to make build reproducible
  (boo#1047218)
* Thu Sep 14 2017 fstrba@suse.com
- Specify java source level 1.6 to allow building with jdk9
* Thu Dec  4 2014 p.drouand@gmail.com
- Remove java-devel dependency; not needed anymore
* Fri Aug  8 2014 sfalken@opensuse.org
- Uploading proper patch, so things will build
* Fri Aug  8 2014 sfalken@opensuse.org
- Updated to 7.0
  * Changed the package name to net.sf.saxon.aelfred to prevent any accidental confusion with the original Microstar code or with David Brownell's version.
  * Fixed several bugs: (1) a bug in namespace handling (where an attribute xxx:name precedes the xmlns:xxx declaration) (2) poor diagnostics when end of file occurs prematurely
  * Subsetting the code to include only the XML non-validating parser and SAX driver, with appropriate changes to the setFeature() and getFeature() methods.
  * Some further changes made by David Brownell up to June 2001 have been incorporated.
- Rebased aelfred-icedtea-build.patch for new source
- Added: aelfred7_0.zip
- Deleted: aelfred.zip
- Updated URLs in specfile
* Fri Jul 11 2014 tchvatal@suse.com
- Cleanup with spec-cleaner and do not version javadoc dir.
* Mon Sep  9 2013 tchvatal@suse.com
- Move from jpackage-utils to javapackage-tools
* Mon Jul 22 2013 coolo@suse.com
- %%ghost is not a %%dir but symlink
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Mar  3 2008 mvyskocil@suse.cz
- merged with jpackage 1.7
- allow to build with icedtea
* Fri Mar 30 2007 ssommer@suse.de
- add unzip to BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Oct 19 2005 jsmeix@suse.de
- Current version 1.2 from JPackage.org
